@REM THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
@REM All Rights Reserved * Licensed Materials - Property of IBM
@REM US Government Users Restricted Rights - Use, duplication or disclosure
@REM restricted by GSA ADP Schedule Contract with IBM Corp.

@REM Configuration Based Update Installer

@REM Command Descriptions
@REM 
@REM The '-efix' option specifies an eFix update.
@REM The '-fixpack' option specifies a FixPack update.
@REM The '-install' option specifies an install action.
@REM The '-uninstall' option specifies an uninstall action.
@REM The '-installDir' option specifies the product install root location.
@REM The '-efixDir' option specifies the eFix directory.
@REM The '-fixpackDir' option specifies the FixPack directory.
@REM The '-efixes' specifies a list of eFixes to install or uninstall.
@REM The '-fixpackID' specifies a FixPack to install or uninstall.
@REM The '-efixDetails' option displays eFix detail information.
@REM The '-fixpackDetails' option displays FixPack detail information.
@REM The '-prereqOverride' option overrides any installation prerequisites.
@REM The '<propertyFile>.properties' option specifies an externally supplied parameters file.

@REM Launch Arguments:
@REM
@REM For EFix Processing:
@REM      updateSilent <propertiesFile>
@REM               ( -installDir <product install root>
@REM		  [ -efix ]
@REM                 [ -efixDir <efix repository root> ]
@REM                 [ -install | -uninstall | -uninstallAll ]
@REM                 [ -efixes <space delimited list of efixes> ]
@REM                 [ -efixJars <space delimited list of efix jars> ]
@REM                 [ -efixDetails ]
@REM                 [ -prereqOverride ] ) |
@REM               ( -help | -? | /help | /? | -usage )
@REM
@REM For FixPack Processing:
@REM  updateSilent <propertiesFile>
@REM	        ( -installDir <product install root>
@REM		  [ -fixpack ]
@REM                 [ ( -install | -uninstall
@REM 		      -fixpackDir <fixpack repository root> ]
@REM 	              -fixpackID <FixPack ID> ]
@REM		      [ ( -ihsInstallDir <IBM HTTP Server root> | -skipIHS ) ]
@REM		      [ ( -mqInstallDir <IBM Embedded Messaging root> | -skipMQ ) ]
@REM		      [ -includeOptional <space delimited list of components> ]
@REM                  [ -fixpackDetails ] ) |
@REM            ( -help | -? | /help | /? | -usage )


@if defined echo (echo %echo% ) else echo off
@setlocal

@REM set DEBUG_UPDATE=yes to turn on debugging statements
set DEBUG_UPDATE=no

@REM CONSOLE_ENCODING controls the output encoding used for stdout/stderr
@REM    console - encoding is correct for a console window
@REM    file    - encoding is the default file encoding for the system
@REM    <other> - the specified encoding is used.  e.g. Cp1252, Cp850, SJIS
SET CONSOLE_ENCODING=-Dws.output.encoding=console

set TYPE=%1
set option=%2
set wcinstallDir=%3
set fixpackID=%4
set installFixpackDir=%5


if /I "TYPE%" == "" goto usage
if /I "%option%" == "" goto usage

@REM Set classpath for eFix commandline installer
SET CLASSPATH="%~dp0installer.jar"

set LaunchTitle=%0
Echo Start of [ %LaunchTitle% ]
Echo.

:Silent
Echo Verifying installer jar:
Echo   [ installer.jar ]
Echo.
IF NOT EXIST "%~dp0installer.jar" GoTo FailSilent
GoTo SetupJDK

:FailSilent
Echo The installer jar file does not exist.  Exiting.
Echo.
GoTo End

:SetupJDK
set JAVA_TMP=%~dp0java_tmp
IF NOT EXIST "%JAVA_TMP%\bin" GoTo PrepareJDK
IF NOT EXIST "%JAVA_TMP%\bin\java.exe" GoTo PrepareJDK
goto UseLocalJDK

:PrepareJDK
IF NOT "%OS%" == "Windows_NT" GoTo Win9xQuoteStrip
GoTo WinNTQuoteStrip

:Win9XQuoteStrip
@REM FOR %%A IN (%JAVA_HOME%) DO SET NEW_JAVA_HOME=%%A
@REM set JAVA_HOME=%NEW_JAVA_HOME%
@REM IF "%JAVA_HOME%" == "" GoTo CheckSetup
IF "%JAVA_HOME%" == "" GoTo CheckSetup
goto UseJavaHome

:WinNTQuoteStrip
set JAVA_HOME_TMP=%JAVA_HOME%
set MOD_JAVA_HOME=%JAVA_HOME_TMP:"=%
set NEW_JAVA_HOME=%MOD_JAVA_HOME:"=%
set JAVA_HOME=%NEW_JAVA_HOME%
IF "%JAVA_HOME%" == "=" GoTo CheckSetup
goto UseJavaHome

:UseLocalJDK
set JAVA_HOME=%JAVA_TMP%
IF "%DEBUG_UPDATE%" == "yes" Echo Using the local copy of the JDK, made previously, for processing:
IF "%DEBUG_UPDATE%" == "yes" Echo   JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
goto LaunchInstaller

:UseJavaHome
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME was set.
IF "%DEBUG_UPDATE%" == "yes" Echo   JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
goto TestJDK

:CheckSetup
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME is not set.
IF "%DEBUG_UPDATE%" == "yes" Echo Attempting to locate setupCmdLine.bat.
IF "%DEBUG_UPDATE%" == "yes" Echo.
IF NOT EXIST "%~dp0..\bin" GoTo FailSetup
IF NOT EXIST "%~dp0..\bin\setupCmdLine.bat" GoTo FailSetup
GoTo CallSetup

:FailSetup
Echo JAVA_HOME must be set before launching the update wizard:
Echo     JAVA_HOME was not set;
Echo     Set JAVA_HOME manually with the install_root/bin/setupCmdLine.bat or setupClient.bat script.
Echo.
Echo (setupCmdLine.bat or setupClient.bat is usually located beneath your
Echo WebSphere Application Server installation, in the 'bin'
Echo directory.)
Echo.
Echo Exiting.
Echo.
GoTo End

:CallSetup
call "%~dp0..\bin\setupCmdLine.bat"
GoTo TestJDK

:TestJDK
IF NOT EXIST "%JAVA_HOME%\bin" GoTo FailJavaHome
IF NOT EXIST "%JAVA_HOME%\bin\java.exe" GoTo FailJavaHome
goto CopyJDK

:FailJavaHome
Echo The JDK was not found within the set JAVA_HOME:
Echo   JAVA_HOME: [ %JAVA_HOME%\bin\java.exe ]
Echo.
Echo Exiting.
Echo.
goto End

:CopyJDK
IF "%DEBUG_UPDATE%" == "yes" Echo Making local copy of the JDK, which is required
IF "%DEBUG_UPDATE%" == "yes" Echo for PTF processing:
IF "%DEBUG_UPDATE%" == "yes" Echo   JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo   JAVA_TMP:  [ %JAVA_TMP% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
IF NOT EXIST "%JAVA_TMP%" MKDIR "%JAVA_TMP%"
IF NOT EXIST "%JAVA_TMP%" GoTo FailedCopyJDK
XCOPY "%JAVA_HOME%" "%JAVA_TMP%" /E /Q
IF NOT EXIST "%JAVA_TMP%\bin" GoTo FailedCopyJDK
IF NOT EXIST "%JAVA_TMP%\bin\java.exe" GoTo FailedCopyJDK
Goto OkCopyJDK

:FailedCopyJDK
Echo The JDK could not be copied into the current directory.
Echo JAVA_HOME: [ %JAVA_HOME% ]
Echo JAVA_TMP:  [ %JAVA_TMP% ]
Echo.
Echo Exiting.
Echo.
goto End

:OKCopyJDK
IF "%DEBUG_UPDATE%" == "yes" Echo The JDK was successfully copied.
IF "%DEBUG_UPDATE%" == "yes" Echo.
Set JAVA_HOME=%JAVA_TMP%
GoTo LaunchInstaller

:LaunchInstaller

if /I "%TYPE%" == "fixpack" goto fixpack
if /I "%TYPE%" == "fix" goto fix
goto usage

:fixpack
if "%option%" == "list" goto listinstall
if "%option%" == "install" goto install
if "%option%" == "uninstall" goto uninstall
goto end

:install
if "%3%" == "" goto usage
if "%4%" == "" goto usage
if "%5%" == "" goto usage
rem echo "%JAVA_HOME%\bin\java" -Dcom.ibm.websphere.update.debug=false -Dcom.ibm.websphere.update.ptf.debug=false %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack "-%option%" -installDir "%wcinstallDir%" -fixpackDir "%installFixpackDir%" -fixpackID %fixpackID% -skipMQ -skipIHS
"%JAVA_HOME%\bin\java" -Dcom.ibm.websphere.update.debug=false -Dcom.ibm.websphere.update.ptf.debug=false %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack "-%option%" -installDir "%wcinstallDir%" -fixpackDir "%installFixpackDir%" -fixpackID %fixpackID% -skipMQ -skipIHS
goto end

:uninstall
if "%3%" == "" goto usage
if "%4%" == "" goto usage
rem echo "%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack "-%option%" -installDir "%wcinstallDir%" -fixpackID %fixpackID%
"%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack "-%option%" -installDir "%wcinstallDir%" -fixpackID %fixpackID%
goto end

:listinstall
if "%3%" == "" goto usage
rem echo "%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack -installDir "%wcinstallDir%"
"%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack -installDir "%wcinstallDir%"
goto end


:fix
if "%option%" == "list" goto listinstall
if "%option%" == "install" goto install
if "%option%" == "uninstall" goto uninstall
goto end

:install
if "%3%" == "" goto usage
if "%4%" == "" goto usage
if "%5%" == "" goto usage
rem echo "%JAVA_HOME%\bin\java" -Dcom.ibm.websphere.update.debug=false -Dcom.ibm.websphere.update.ptf.debug=false %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack "-%option%" -installDir "%wcinstallDir%" -fixpackDir "%installFixpackDir%" -fixpackID %fixpackID%
"%JAVA_HOME%\bin\java" -Dcom.ibm.websphere.update.debug=false -Dcom.ibm.websphere.update.ptf.debug=false %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -efix "-%option%" -installDir "%wcinstallDir%" -efixDir "%installFixpackDir%"  -efixes %fixpackID%
goto end

:uninstall
if "%3%" == "" goto usage
if "%4%" == "" goto usage
rem echo "%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack "-%option%" -installDir "%wcinstallDir%" -fixpackID %fixpackID%
"%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -efix "-%option%" -installDir "%wcinstallDir%" -efixes %fixpackID%
goto end

:listinstall
if "%3%" == "" goto usage
rem echo "%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -fixpack -installDir "%wcinstallDir%"
"%JAVA_HOME%\bin\java" %CONSOLE_ENCODING% -Xmx256m -cp "%~dp0lib;%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar" com.ibm.websphere.update.silent.SilentArgsCollector -efix -installDir "%wcinstallDir%"
goto end


:usage
echo "For FixPack:"
echo "Usage: %0 fixpack [ install | uninstall | list ] wcinstallDir [ fixpackID ] [ installFixpackDir ] "
echo "For example, %0 fixpack install C:\WebSphere\CommerceServer55 wc55BE_fp1_<OS> C:\temp"
echo "For example, %0 fixpack uninstall C:\WebSphere\CommerceServer55 wc55BE_fp1_<OS>"
echo "For example, %0 fixpack list C:\WebSphere\CommerceServer55"
echo " "
echo "For Fix:"
echo "Usage: %0 fix [ install | uninstall | list ] wcinstallDir [ ID ] [ installFixDir ]"
echo "For example, %0 fix install C:\WebSphere\CommerceServer55 JR1111 C:\temp"
echo "For example, %0 fix uninstall C:\WebSphere\CommerceServer55 JR1111"
echo "For example, %0 fix list C:\WebSphere\CommerceServer55"
goto end


:End
Echo.
Echo End of [ %0 ]
Echo.
endlocal

